Config

Struct Config 

pub struct Config {
    pub format_costs: Option<Vec<FormatCostEntry>>,
}
This type is fidl::Persist()’ed in the sysmem_config.persistent_fidl file within the sysmem domain config by the assembly tool, and read by the sysmem driver.

Normally json[5] would be preferable for config, but we generate this config in rust using FIDL types (to avoid repetition and to take advantage of FIDL rust codegen), and there’s no json schema for FIDL types.

Currently there is no mechanism to change anything in this config at runtime or from boot to boot. This config is static per run of the assembly tool.

See src/lib/assembly/config_schema/src/platform_config/sysmem_config.rs for aspects of sysmem config which are specified directly inline in board info or assembly platform config. The two parts of sysmem config don’t (currently) overlap. The config here is for aspects of sysmem config which would be too verbose for direct inclusion in board info or assembly platform config. In addition, some/most of the pixel format cost entries are programmatically generated (as of this comment).

Prior to aggregation by assembly tool, there are multiple .persistent_fidl files each storing its own Config instance. The board info and assembly platform config lists the input persistent_fidl files, with board info logically before assembly platform config. The overall list of files is processed, which allows later files to override/replace info in prior files.

Because this type is only intended for use with persistent fidl, where the length of a serialized instance isn’t bounded, we don’t bound the internal vector element counts.

Fields

format_costs: Option<Vec<FormatCostEntry>>