pub struct FormatCostKey {
pub pixel_format: Option<PixelFormat>,
pub pixel_format_modifier: Option<PixelFormatModifier>,
pub buffer_usage_bits: Option<BufferUsage>,
}Expand description
Entries which have the same pixel_format, pixel_format_modifier, and required_usage_bits as a previous entry will override that previous entry. For matching purposes, an absent pixel_format_modifier matches LINEAR, and an absent required_buffer_usage_bits matches all-0 usage bits.
Fields
pixel_format: Option<PixelFormat>pixel_format_modifier: Option<PixelFormatModifier>buffer_usage_bits: Option<BufferUsage>Trait Implementations
Sourceimpl Clone for FormatCostKey
impl Clone for FormatCostKey
Sourcefn clone(&self) -> FormatCostKey
fn clone(&self) -> FormatCostKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FormatCostKey
impl Debug for FormatCostKey
Sourceimpl Default for FormatCostKey
impl Default for FormatCostKey
Sourcefn default() -> FormatCostKey
fn default() -> FormatCostKey
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<FormatCostKey<'static>, ___E> for &'a FormatCostKeywhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<FormatCostKey<'static>, ___E> for &'a FormatCostKeywhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<FormatCostKey<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<FormatCostKey<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<FormatCostKey<'static>, ___E> for FormatCostKeywhere
___E: Encoder + ?Sized,
impl<___E> Encode<FormatCostKey<'static>, ___E> for FormatCostKeywhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<FormatCostKey<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<FormatCostKey<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<FormatCostKey<'de>> for FormatCostKey
impl<'de> FromWire<FormatCostKey<'de>> for FormatCostKey
Sourcefn from_wire(wire_: FormatCostKey<'de>) -> Self
fn from_wire(wire_: FormatCostKey<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<FormatCostKey<'de>> for FormatCostKey
impl<'de> FromWireRef<FormatCostKey<'de>> for FormatCostKey
Sourcefn from_wire_ref(wire: &FormatCostKey<'de>) -> Self
fn from_wire_ref(wire: &FormatCostKey<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for FormatCostKey
impl Hash for FormatCostKey
Sourceimpl Ord for FormatCostKey
impl Ord for FormatCostKey
Sourcefn cmp(&self, other: &FormatCostKey) -> Ordering
fn cmp(&self, other: &FormatCostKey) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FormatCostKey
impl PartialEq for FormatCostKey
Sourcefn eq(&self, other: &FormatCostKey) -> bool
fn eq(&self, other: &FormatCostKey) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for FormatCostKey
impl PartialOrd for FormatCostKey
impl Copy for FormatCostKey
impl Eq for FormatCostKey
impl StructuralPartialEq for FormatCostKey