pub struct Heap {
pub heap_type: Option<String>,
pub id: Option<u64>,
}Expand description
A reference to a heap instance.
A given heap instance can have more than one Heap which can be used to
refer to the heap instance. Comparing Heap tables without knowledge of
these Heap aliases is not a reliable way to determine if two Heap tables
refer to the same heap (matching means yes, but not matching means maybe).
Allowing heap aliases makes renaming Heap.type(s) easier.
Fields
heap_type: Option<String>id: Option<u64>Trait Implementations
Sourceimpl<'a, ___E> Encode<Heap<'static>, ___E> for &'a Heapwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<Heap<'static>, ___E> for &'a Heapwhere
___E: Encoder + ?Sized,
Sourceimpl<___E> Encode<Heap<'static>, ___E> for Heapwhere
___E: Encoder + ?Sized,
impl<___E> Encode<Heap<'static>, ___E> for Heapwhere
___E: Encoder + ?Sized,
Sourceimpl<'de> FromWireRef<Heap<'de>> for Heap
impl<'de> FromWireRef<Heap<'de>> for Heap
Sourcefn from_wire_ref(wire: &Heap<'de>) -> Self
fn from_wire_ref(wire: &Heap<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for Heap
impl Ord for Heap
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Heap
impl PartialOrd for Heap
impl Eq for Heap
impl StructuralPartialEq for Heap