pub struct ImageFormatConstraints {Show 20 fields
pub pixel_format: Option<PixelFormat>,
pub pixel_format_modifier: Option<PixelFormatModifier>,
pub color_spaces: Option<Vec<ColorSpace>>,
pub min_size: Option<SizeU>,
pub max_size: Option<SizeU>,
pub min_bytes_per_row: Option<u32>,
pub max_bytes_per_row: Option<u32>,
pub max_width_times_height: Option<u64>,
pub size_alignment: Option<SizeU>,
pub display_rect_alignment: Option<SizeU>,
pub required_min_size: Option<SizeU>,
pub required_max_size: Option<SizeU>,
pub bytes_per_row_divisor: Option<u32>,
pub start_offset_divisor: Option<u32>,
pub pixel_format_and_modifiers: Option<Vec<PixelFormatAndModifier>>,
pub require_bytes_per_row_at_pixel_boundary: Option<bool>,
pub is_alpha_present: Option<bool>,
pub required_max_size_list: Option<Vec<SizeU>>,
pub pad_for_block_size: Option<SizeU>,
pub pad_beyond_image_size_bytes: Option<u64>,
}Expand description
Describes constraints on layout of image data in buffers.
Fields
pixel_format: Option<PixelFormat>pixel_format_modifier: Option<PixelFormatModifier>color_spaces: Option<Vec<ColorSpace>>min_size: Option<SizeU>max_size: Option<SizeU>min_bytes_per_row: Option<u32>max_bytes_per_row: Option<u32>max_width_times_height: Option<u64>size_alignment: Option<SizeU>display_rect_alignment: Option<SizeU>required_min_size: Option<SizeU>required_max_size: Option<SizeU>bytes_per_row_divisor: Option<u32>start_offset_divisor: Option<u32>pixel_format_and_modifiers: Option<Vec<PixelFormatAndModifier>>require_bytes_per_row_at_pixel_boundary: Option<bool>is_alpha_present: Option<bool>required_max_size_list: Option<Vec<SizeU>>pad_for_block_size: Option<SizeU>pad_beyond_image_size_bytes: Option<u64>Trait Implementations
Sourceimpl Clone for ImageFormatConstraints
impl Clone for ImageFormatConstraints
Sourcefn clone(&self) -> ImageFormatConstraints
fn clone(&self) -> ImageFormatConstraints
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImageFormatConstraints
impl Debug for ImageFormatConstraints
Sourceimpl Default for ImageFormatConstraints
impl Default for ImageFormatConstraints
Sourcefn default() -> ImageFormatConstraints
fn default() -> ImageFormatConstraints
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<ImageFormatConstraints<'static>, ___E> for &'a ImageFormatConstraintswhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<ImageFormatConstraints<'static>, ___E> for &'a ImageFormatConstraintswhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<ImageFormatConstraints<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<ImageFormatConstraints<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ImageFormatConstraints<'static>, ___E> for ImageFormatConstraintswhere
___E: Encoder + ?Sized,
impl<___E> Encode<ImageFormatConstraints<'static>, ___E> for ImageFormatConstraintswhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<ImageFormatConstraints<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<ImageFormatConstraints<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<ImageFormatConstraints<'de>> for ImageFormatConstraints
impl<'de> FromWire<ImageFormatConstraints<'de>> for ImageFormatConstraints
Sourcefn from_wire(wire_: ImageFormatConstraints<'de>) -> Self
fn from_wire(wire_: ImageFormatConstraints<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ImageFormatConstraints<'de>> for ImageFormatConstraints
impl<'de> FromWireRef<ImageFormatConstraints<'de>> for ImageFormatConstraints
Sourcefn from_wire_ref(wire: &ImageFormatConstraints<'de>) -> Self
fn from_wire_ref(wire: &ImageFormatConstraints<'de>) -> Self
Converts the given reference to this type.
Sourceimpl PartialEq for ImageFormatConstraints
impl PartialEq for ImageFormatConstraints
Sourcefn eq(&self, other: &ImageFormatConstraints) -> bool
fn eq(&self, other: &ImageFormatConstraints) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ImageFormatConstraints