pub struct SingleBufferSettings {
pub buffer_settings: Option<BufferMemorySettings>,
pub image_format_constraints: Option<ImageFormatConstraints>,
}Expand description
These settings and constraints apply to all the buffers in the collection.
Fields
buffer_settings: Option<BufferMemorySettings>image_format_constraints: Option<ImageFormatConstraints>Trait Implementations
Sourceimpl Clone for SingleBufferSettings
impl Clone for SingleBufferSettings
Sourcefn clone(&self) -> SingleBufferSettings
fn clone(&self) -> SingleBufferSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SingleBufferSettings
impl Debug for SingleBufferSettings
Sourceimpl Default for SingleBufferSettings
impl Default for SingleBufferSettings
Sourcefn default() -> SingleBufferSettings
fn default() -> SingleBufferSettings
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<SingleBufferSettings<'static>, ___E> for &'a SingleBufferSettingswhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<SingleBufferSettings<'static>, ___E> for &'a SingleBufferSettingswhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<SingleBufferSettings<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<SingleBufferSettings<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SingleBufferSettings<'static>, ___E> for SingleBufferSettingswhere
___E: Encoder + ?Sized,
impl<___E> Encode<SingleBufferSettings<'static>, ___E> for SingleBufferSettingswhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<SingleBufferSettings<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<SingleBufferSettings<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<SingleBufferSettings<'de>> for SingleBufferSettings
impl<'de> FromWire<SingleBufferSettings<'de>> for SingleBufferSettings
Sourcefn from_wire(wire_: SingleBufferSettings<'de>) -> Self
fn from_wire(wire_: SingleBufferSettings<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<SingleBufferSettings<'de>> for SingleBufferSettings
impl<'de> FromWireRef<SingleBufferSettings<'de>> for SingleBufferSettings
Sourcefn from_wire_ref(wire: &SingleBufferSettings<'de>) -> Self
fn from_wire_ref(wire: &SingleBufferSettings<'de>) -> Self
Converts the given reference to this type.
Sourceimpl PartialEq for SingleBufferSettings
impl PartialEq for SingleBufferSettings
Sourcefn eq(&self, other: &SingleBufferSettings) -> bool
fn eq(&self, other: &SingleBufferSettings) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SingleBufferSettings